vfbLib.parsers.binary.BinaryTableParser
=======================================

.. currentmodule:: vfbLib.parsers.binary

.. autoclass:: BinaryTableParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BinaryTableParser.__init__
      ~BinaryTableParser.parse
      ~BinaryTableParser.parse_hex
      ~BinaryTableParser.read_double
      ~BinaryTableParser.read_doubles
      ~BinaryTableParser.read_float
      ~BinaryTableParser.read_floats
      ~BinaryTableParser.read_int16
      ~BinaryTableParser.read_int32
      ~BinaryTableParser.read_int8
      ~BinaryTableParser.read_str
      ~BinaryTableParser.read_str_all
      ~BinaryTableParser.read_uint16
      ~BinaryTableParser.read_uint32
      ~BinaryTableParser.read_uint8
      ~BinaryTableParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BinaryTableParser.encoding
      ~BinaryTableParser.master_count
      ~BinaryTableParser.stream
      ~BinaryTableParser.ttStemsH_count
      ~BinaryTableParser.ttStemsV_count
   
   